@@ -4,7 +4,7 @@ use vars qw( $VERSION );
 use POSIX ();
 use Sys::Info::Constants qw( :unknown );
 
-$VERSION = '0.69_01';
+$VERSION = '0.69_07';
 
 # So, we don't support $^O yet, but we can try to emulate some features
 
@@ -47,10 +47,20 @@ sub meta {
 
 sub tz {
     my $self = shift;
-    return exists $ENV{TZ} ? $ENV{TZ} : undef;
+    return exists $ENV{TZ}
+         ? $ENV{TZ}
+         : do {
+               require POSIX;
+               strftime("%Z", localtime);
+           };
 }
 
-sub fs { +() }
+sub fs {
+    my $self = shift;
+    return(
+        unknown => 1,
+    );
+}
 
 sub name {
     my $self  = shift;
